==> snapd_2.27.5~14.04.tar.xz: snappy.upstream/README.md <==
[![Build Status][travis-image]][travis-url]
[![Go Report Card][goreportcard-image]][goreportcard-url]
[![codecov][codecov-image]][codecov-url]
 
## Snaps

Package any app for every Linux desktop, server, cloud or device.

Snaps are faster to install, easier to create, safer to run, and they update
automatically and transactionally so your app is always fresh and never
broken. You can bring your own build infrastructure or use ours.

Head over to [snapcraft.io](https://snapcraft.io) to get started.

## Development

To get started with development off the snapd code itself, please check
out [HACKING.md](https://github.com/snapcore/snapd/blob/master/HACKING.md)
for in-depth details.

## Reporting bugs

If you have found an issue with the application, please [file a bug](https://bugs.launchpad.net/snappy/+filebug) on the [bugs list on Launchpad](https://bugs.launchpad.net/snappy/).

## Get in touch

We're friendly! Talk to us on [IRC](https://webchat.freenode.net/?channels=snappy)
or on [our mailing list](https://lists.snapcraft.io/mailman/listinfo/snapcraft).

Get news and stay up to date on [Twitter](https://twitter.com/snapcraftio),
[Google+](https://plus.google.com/+SnapcraftIo) or
[Facebook](https://www.facebook.com/snapcraftio).



[travis-image]: https://travis-ci.org/snapcore/snapd.svg?branch=master
[travis-url]: https://travis-ci.org/snapcore/snapd

[goreportcard-image]: https://goreportcard.com/badge/github.com/snapcore/snapd
[goreportcard-url]: https://goreportcard.com/report/github.com/snapcore/snapd

[coveralls-image]: https://coveralls.io/repos/snapcore/snapd/badge.svg?branch=master&service=github
[coveralls-url]: https://coveralls.io/github/snapcore/snapd?branch=master

[codecov-url]: https://codecov.io/gh/snapcore/snapd
[codecov-image]: https://codecov.io/gh/snapcore/snapd/branch/master/graph/badge.svg

==> snapd_2.29.4.2+17.04.tar.xz: snappy.upstream/README.md <==
[![Build Status][travis-image]][travis-url]
[![Go Report Card][goreportcard-image]][goreportcard-url]
[![codecov][codecov-image]][codecov-url]
 
## Snaps

Package any app for every Linux desktop, server, cloud or device.

Snaps are faster to install, easier to create, safer to run, and they update
automatically and transactionally so your app is always fresh and never
broken. You can bring your own build infrastructure or use ours.

Head over to [snapcraft.io](https://snapcraft.io) to get started.

## Development

To get started with development off the snapd code itself, please check
out [HACKING.md](https://github.com/snapcore/snapd/blob/master/HACKING.md)
for in-depth details.

## Reporting bugs

If you have found an issue with the application, please [file a bug](https://bugs.launchpad.net/snappy/+filebug) on the [bugs list on Launchpad](https://bugs.launchpad.net/snappy/).

## Get in touch

We're friendly! Talk to us on 
[IRC](https://webchat.freenode.net/?channels=snappy),
[Rocket Chat](https://rocket.ubuntu.com/channel/snappy),
or on [our forums](https://forum.snapcraft.io/).

Get news and stay up to date on [Twitter](https://twitter.com/snapcraftio),
[Google+](https://plus.google.com/+SnapcraftIo) or
[Facebook](https://www.facebook.com/snapcraftio).



[travis-image]: https://travis-ci.org/snapcore/snapd.svg?branch=master
[travis-url]: https://travis-ci.org/snapcore/snapd

[goreportcard-image]: https://goreportcard.com/badge/github.com/snapcore/snapd
[goreportcard-url]: https://goreportcard.com/report/github.com/snapcore/snapd

[coveralls-image]: https://coveralls.io/repos/snapcore/snapd/badge.svg?branch=master&service=github
[coveralls-url]: https://coveralls.io/github/snapcore/snapd?branch=master

[codecov-url]: https://codecov.io/gh/snapcore/snapd
[codecov-image]: https://codecov.io/gh/snapcore/snapd/branch/master/graph/badge.svg
